@@ -6,32 +6,29 @@ def test_evaluate_new_solutions():
     from spotPython.fun.objectivefunctions import analytical
     from spotPython.spot.spot import Spot
     from spotPython.utils.repair import repair_non_numeric
-    import pytest
-    from spotPython.utils.init import fun_control_init, optimizer_control_init, surrogate_control_init, design_control_init
+    from spotPython.utils.init import fun_control_init, design_control_init
 
     fun = analytical().fun_sphere
 
     nn = 3
     ni = 4
 
-    fun_control=fun_control_init(lower=np.array([-10,-1]),
-        upper=np.array([10,1]),
-        n_points=nn,)
-    design_control = design_control_init(init_size=ni, repeats=1)
-    spot_test = Spot(
-        fun=fun,
-        fun_control=fun_control,
-        design_control=design_control
+    fun_control = fun_control_init(
+        lower=np.array([-10, -1]),
+        upper=np.array([10, 1]),
+        n_points=nn,
     )
-
+    design_control = design_control_init(init_size=ni, repeats=1)
+    spot_test = Spot(fun=fun, fun_control=fun_control, design_control=design_control)
 
     # (S-2) Initial Design:
-    spot_test.X = spot_test.generate_design(size=spot_test.design_control["init_size"],
-                                            repeats=spot_test.design_control["repeats"], 
-                                            lower=spot_test.lower,
-                                            upper=spot_test.upper)
-    spot_test.X = repair_non_numeric(spot_test.X,
-                                        spot_test.var_type)
+    spot_test.X = spot_test.generate_design(
+        size=spot_test.design_control["init_size"],
+        repeats=spot_test.design_control["repeats"],
+        lower=spot_test.lower,
+        upper=spot_test.upper,
+    )
+    spot_test.X = repair_non_numeric(spot_test.X, spot_test.var_type)
 
     # (S-3): Eval initial design:
     spot_test.y = spot_test.fun(spot_test.X)
